@@ -6,9 +6,9 @@ Type annotations for transfer service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_transfer.literals import DomainType
+    from mypy_boto3_transfer.literals import CustomStepStatusType
 
-    data: DomainType = "EFS"
+    data: CustomStepStatusType = "FAILURE"
     ```
 """
 import sys
@@ -20,20 +20,30 @@ else:
 
 
 __all__ = (
+    "CustomStepStatusType",
     "DomainType",
     "EndpointTypeType",
+    "ExecutionErrorTypeType",
+    "ExecutionStatusType",
     "HomeDirectoryTypeType",
     "IdentityProviderTypeType",
     "ListServersPaginatorName",
+    "OverwriteExistingType",
     "ProtocolType",
     "StateType",
+    "WorkflowStepTypeType",
 )
 
 
+CustomStepStatusType = Literal["FAILURE", "SUCCESS"]
 DomainType = Literal["EFS", "S3"]
 EndpointTypeType = Literal["PUBLIC", "VPC", "VPC_ENDPOINT"]
+ExecutionErrorTypeType = Literal["PERMISSION_DENIED"]
+ExecutionStatusType = Literal["COMPLETED", "EXCEPTION", "HANDLING_EXCEPTION", "IN_PROGRESS"]
 HomeDirectoryTypeType = Literal["LOGICAL", "PATH"]
 IdentityProviderTypeType = Literal["API_GATEWAY", "AWS_DIRECTORY_SERVICE", "SERVICE_MANAGED"]
 ListServersPaginatorName = Literal["list_servers"]
+OverwriteExistingType = Literal["FALSE", "TRUE"]
 ProtocolType = Literal["FTP", "FTPS", "SFTP"]
 StateType = Literal["OFFLINE", "ONLINE", "STARTING", "START_FAILED", "STOPPING", "STOP_FAILED"]
+WorkflowStepTypeType = Literal["COPY", "CUSTOM", "DELETE", "TAG"]
