@@ -6,9 +6,9 @@ Type annotations for transfer service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_transfer.type_defs import CreateAccessRequestRequestTypeDef
+    from mypy_boto3_transfer.type_defs import CopyStepDetailsTypeDef
 
-    data: CreateAccessRequestRequestTypeDef = {...}
+    data: CopyStepDetailsTypeDef = {...}
     ```
 """
 import sys
@@ -16,14 +16,22 @@ from datetime import datetime
 from typing import Any, Dict, List
 
 from .literals import (
+    CustomStepStatusType,
     DomainType,
     EndpointTypeType,
+    ExecutionStatusType,
     HomeDirectoryTypeType,
     IdentityProviderTypeType,
+    OverwriteExistingType,
     ProtocolType,
     StateType,
+    WorkflowStepTypeType,
 )
 
+if sys.version_info >= (3, 8):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -31,35 +39,55 @@ else:
 
 
 __all__ = (
+    "CopyStepDetailsTypeDef",
     "CreateAccessRequestRequestTypeDef",
     "CreateAccessResponseTypeDef",
     "CreateServerRequestRequestTypeDef",
     "CreateServerResponseTypeDef",
     "CreateUserRequestRequestTypeDef",
     "CreateUserResponseTypeDef",
+    "CreateWorkflowRequestRequestTypeDef",
+    "CreateWorkflowResponseTypeDef",
+    "CustomStepDetailsTypeDef",
     "DeleteAccessRequestRequestTypeDef",
     "DeleteServerRequestRequestTypeDef",
     "DeleteSshPublicKeyRequestRequestTypeDef",
+    "DeleteStepDetailsTypeDef",
     "DeleteUserRequestRequestTypeDef",
+    "DeleteWorkflowRequestRequestTypeDef",
     "DescribeAccessRequestRequestTypeDef",
     "DescribeAccessResponseTypeDef",
+    "DescribeExecutionRequestRequestTypeDef",
+    "DescribeExecutionResponseTypeDef",
     "DescribeSecurityPolicyRequestRequestTypeDef",
     "DescribeSecurityPolicyResponseTypeDef",
     "DescribeServerRequestRequestTypeDef",
     "DescribeServerResponseTypeDef",
     "DescribeUserRequestRequestTypeDef",
     "DescribeUserResponseTypeDef",
+    "DescribeWorkflowRequestRequestTypeDef",
+    "DescribeWorkflowResponseTypeDef",
     "DescribedAccessTypeDef",
+    "DescribedExecutionTypeDef",
     "DescribedSecurityPolicyTypeDef",
     "DescribedServerTypeDef",
     "DescribedUserTypeDef",
+    "DescribedWorkflowTypeDef",
+    "EfsFileLocationTypeDef",
     "EndpointDetailsTypeDef",
+    "ExecutionErrorTypeDef",
+    "ExecutionResultsTypeDef",
+    "ExecutionStepResultTypeDef",
+    "FileLocationTypeDef",
     "HomeDirectoryMapEntryTypeDef",
     "IdentityProviderDetailsTypeDef",
     "ImportSshPublicKeyRequestRequestTypeDef",
     "ImportSshPublicKeyResponseTypeDef",
+    "InputFileLocationTypeDef",
     "ListAccessesRequestRequestTypeDef",
     "ListAccessesResponseTypeDef",
+    "ListExecutionsRequestRequestTypeDef",
+    "ListExecutionsResponseTypeDef",
     "ListSecurityPoliciesRequestRequestTypeDef",
     "ListSecurityPoliciesResponseTypeDef",
     "ListServersRequestRequestTypeDef",
@@ -68,17 +96,28 @@ __all__ = (
     "ListTagsForResourceResponseTypeDef",
     "ListUsersRequestRequestTypeDef",
     "ListUsersResponseTypeDef",
+    "ListWorkflowsRequestRequestTypeDef",
+    "ListWorkflowsResponseTypeDef",
     "ListedAccessTypeDef",
+    "ListedExecutionTypeDef",
     "ListedServerTypeDef",
     "ListedUserTypeDef",
+    "ListedWorkflowTypeDef",
+    "LoggingConfigurationTypeDef",
     "PaginatorConfigTypeDef",
     "PosixProfileTypeDef",
     "ProtocolDetailsTypeDef",
     "ResponseMetadataTypeDef",
+    "S3FileLocationTypeDef",
+    "S3InputFileLocationTypeDef",
+    "S3TagTypeDef",
+    "SendWorkflowStepStateRequestRequestTypeDef",
+    "ServiceMetadataTypeDef",
     "SshPublicKeyTypeDef",
     "StartServerRequestRequestTypeDef",
     "StopServerRequestRequestTypeDef",
     "TagResourceRequestRequestTypeDef",
+    "TagStepDetailsTypeDef",
     "TagTypeDef",
     "TestIdentityProviderRequestRequestTypeDef",
     "TestIdentityProviderResponseTypeDef",
@@ -89,6 +128,20 @@ __all__ = (
     "UpdateServerResponseTypeDef",
     "UpdateUserRequestRequestTypeDef",
     "UpdateUserResponseTypeDef",
+    "UserDetailsTypeDef",
+    "WorkflowDetailTypeDef",
+    "WorkflowDetailsTypeDef",
+    "WorkflowStepTypeDef",
+)
+
+CopyStepDetailsTypeDef = TypedDict(
+    "CopyStepDetailsTypeDef",
+    {
+        "Name": str,
+        "DestinationFileLocation": "InputFileLocationTypeDef",
+        "OverwriteExisting": OverwriteExistingType,
+    },
+    total=False,
 )
 
 _RequiredCreateAccessRequestRequestTypeDef = TypedDict(
@@ -141,6 +194,7 @@ CreateServerRequestRequestTypeDef = TypedDict(
         "Protocols": List[ProtocolType],
         "SecurityPolicyName": str,
         "Tags": List["TagTypeDef"],
+        "WorkflowDetails": "WorkflowDetailsTypeDef",
     },
     total=False,
 )
@@ -191,6 +245,47 @@ CreateUserResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredCreateWorkflowRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateWorkflowRequestRequestTypeDef",
+    {
+        "Steps": List["WorkflowStepTypeDef"],
+    },
+)
+_OptionalCreateWorkflowRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateWorkflowRequestRequestTypeDef",
+    {
+        "Description": str,
+        "OnExceptionSteps": List["WorkflowStepTypeDef"],
+        "Tags": List["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateWorkflowRequestRequestTypeDef(
+    _RequiredCreateWorkflowRequestRequestTypeDef, _OptionalCreateWorkflowRequestRequestTypeDef
+):
+    pass
+
+
+CreateWorkflowResponseTypeDef = TypedDict(
+    "CreateWorkflowResponseTypeDef",
+    {
+        "WorkflowId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+CustomStepDetailsTypeDef = TypedDict(
+    "CustomStepDetailsTypeDef",
+    {
+        "Name": str,
+        "Target": str,
+        "TimeoutSeconds": int,
+    },
+    total=False,
+)
+
 DeleteAccessRequestRequestTypeDef = TypedDict(
     "DeleteAccessRequestRequestTypeDef",
     {
@@ -215,6 +310,14 @@ DeleteSshPublicKeyRequestRequestTypeDef = TypedDict(
     },
 )
 
+DeleteStepDetailsTypeDef = TypedDict(
+    "DeleteStepDetailsTypeDef",
+    {
+        "Name": str,
+    },
+    total=False,
+)
+
 DeleteUserRequestRequestTypeDef = TypedDict(
     "DeleteUserRequestRequestTypeDef",
     {
@@ -223,6 +326,13 @@ DeleteUserRequestRequestTypeDef = TypedDict(
     },
 )
 
+DeleteWorkflowRequestRequestTypeDef = TypedDict(
+    "DeleteWorkflowRequestRequestTypeDef",
+    {
+        "WorkflowId": str,
+    },
+)
+
 DescribeAccessRequestRequestTypeDef = TypedDict(
     "DescribeAccessRequestRequestTypeDef",
     {
@@ -240,6 +350,23 @@ DescribeAccessResponseTypeDef = TypedDict(
     },
 )
 
+DescribeExecutionRequestRequestTypeDef = TypedDict(
+    "DescribeExecutionRequestRequestTypeDef",
+    {
+        "ExecutionId": str,
+        "WorkflowId": str,
+    },
+)
+
+DescribeExecutionResponseTypeDef = TypedDict(
+    "DescribeExecutionResponseTypeDef",
+    {
+        "WorkflowId": str,
+        "Execution": "DescribedExecutionTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DescribeSecurityPolicyRequestRequestTypeDef = TypedDict(
     "DescribeSecurityPolicyRequestRequestTypeDef",
     {
@@ -287,6 +414,21 @@ DescribeUserResponseTypeDef = TypedDict(
     },
 )
 
+DescribeWorkflowRequestRequestTypeDef = TypedDict(
+    "DescribeWorkflowRequestRequestTypeDef",
+    {
+        "WorkflowId": str,
+    },
+)
+
+DescribeWorkflowResponseTypeDef = TypedDict(
+    "DescribeWorkflowResponseTypeDef",
+    {
+        "Workflow": "DescribedWorkflowTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DescribedAccessTypeDef = TypedDict(
     "DescribedAccessTypeDef",
     {
@@ -301,6 +443,21 @@ DescribedAccessTypeDef = TypedDict(
     total=False,
 )
 
+DescribedExecutionTypeDef = TypedDict(
+    "DescribedExecutionTypeDef",
+    {
+        "ExecutionId": str,
+        "InitialFileLocation": "FileLocationTypeDef",
+        "ServiceMetadata": "ServiceMetadataTypeDef",
+        "ExecutionRole": str,
+        "LoggingConfiguration": "LoggingConfigurationTypeDef",
+        "PosixProfile": "PosixProfileTypeDef",
+        "Status": ExecutionStatusType,
+        "Results": "ExecutionResultsTypeDef",
+    },
+    total=False,
+)
+
 _RequiredDescribedSecurityPolicyTypeDef = TypedDict(
     "_RequiredDescribedSecurityPolicyTypeDef",
     {
@@ -350,6 +507,7 @@ _OptionalDescribedServerTypeDef = TypedDict(
         "State": StateType,
         "Tags": List["TagTypeDef"],
         "UserCount": int,
+        "WorkflowDetails": "WorkflowDetailsTypeDef",
     },
     total=False,
 )
@@ -386,6 +544,40 @@ class DescribedUserTypeDef(_RequiredDescribedUserTypeDef, _OptionalDescribedUser
     pass
 
 
+_RequiredDescribedWorkflowTypeDef = TypedDict(
+    "_RequiredDescribedWorkflowTypeDef",
+    {
+        "Arn": str,
+    },
+)
+_OptionalDescribedWorkflowTypeDef = TypedDict(
+    "_OptionalDescribedWorkflowTypeDef",
+    {
+        "Description": str,
+        "Steps": List["WorkflowStepTypeDef"],
+        "OnExceptionSteps": List["WorkflowStepTypeDef"],
+        "WorkflowId": str,
+        "Tags": List["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class DescribedWorkflowTypeDef(
+    _RequiredDescribedWorkflowTypeDef, _OptionalDescribedWorkflowTypeDef
+):
+    pass
+
+
+EfsFileLocationTypeDef = TypedDict(
+    "EfsFileLocationTypeDef",
+    {
+        "FileSystemId": str,
+        "Path": str,
+    },
+    total=False,
+)
+
 EndpointDetailsTypeDef = TypedDict(
     "EndpointDetailsTypeDef",
     {
@@ -398,6 +590,42 @@ EndpointDetailsTypeDef = TypedDict(
     total=False,
 )
 
+ExecutionErrorTypeDef = TypedDict(
+    "ExecutionErrorTypeDef",
+    {
+        "Type": Literal["PERMISSION_DENIED"],
+        "Message": str,
+    },
+)
+
+ExecutionResultsTypeDef = TypedDict(
+    "ExecutionResultsTypeDef",
+    {
+        "Steps": List["ExecutionStepResultTypeDef"],
+        "OnExceptionSteps": List["ExecutionStepResultTypeDef"],
+    },
+    total=False,
+)
+
+ExecutionStepResultTypeDef = TypedDict(
+    "ExecutionStepResultTypeDef",
+    {
+        "StepType": WorkflowStepTypeType,
+        "Outputs": str,
+        "Error": "ExecutionErrorTypeDef",
+    },
+    total=False,
+)
+
+FileLocationTypeDef = TypedDict(
+    "FileLocationTypeDef",
+    {
+        "S3FileLocation": "S3FileLocationTypeDef",
+        "EfsFileLocation": "EfsFileLocationTypeDef",
+    },
+    total=False,
+)
+
 HomeDirectoryMapEntryTypeDef = TypedDict(
     "HomeDirectoryMapEntryTypeDef",
     {
@@ -435,6 +663,15 @@ ImportSshPublicKeyResponseTypeDef = TypedDict(
     },
 )
 
+InputFileLocationTypeDef = TypedDict(
+    "InputFileLocationTypeDef",
+    {
+        "S3FileLocation": "S3InputFileLocationTypeDef",
+        "EfsFileLocation": "EfsFileLocationTypeDef",
+    },
+    total=False,
+)
+
 _RequiredListAccessesRequestRequestTypeDef = TypedDict(
     "_RequiredListAccessesRequestRequestTypeDef",
     {
@@ -467,6 +704,38 @@ ListAccessesResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredListExecutionsRequestRequestTypeDef = TypedDict(
+    "_RequiredListExecutionsRequestRequestTypeDef",
+    {
+        "WorkflowId": str,
+    },
+)
+_OptionalListExecutionsRequestRequestTypeDef = TypedDict(
+    "_OptionalListExecutionsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListExecutionsRequestRequestTypeDef(
+    _RequiredListExecutionsRequestRequestTypeDef, _OptionalListExecutionsRequestRequestTypeDef
+):
+    pass
+
+
+ListExecutionsResponseTypeDef = TypedDict(
+    "ListExecutionsResponseTypeDef",
+    {
+        "NextToken": str,
+        "WorkflowId": str,
+        "Executions": List["ListedExecutionTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ListSecurityPoliciesRequestRequestTypeDef = TypedDict(
     "ListSecurityPoliciesRequestRequestTypeDef",
     {
@@ -568,6 +837,24 @@ ListUsersResponseTypeDef = TypedDict(
     },
 )
 
+ListWorkflowsRequestRequestTypeDef = TypedDict(
+    "ListWorkflowsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+ListWorkflowsResponseTypeDef = TypedDict(
+    "ListWorkflowsResponseTypeDef",
+    {
+        "NextToken": str,
+        "Workflows": List["ListedWorkflowTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ListedAccessTypeDef = TypedDict(
     "ListedAccessTypeDef",
     {
@@ -579,6 +866,17 @@ ListedAccessTypeDef = TypedDict(
     total=False,
 )
 
+ListedExecutionTypeDef = TypedDict(
+    "ListedExecutionTypeDef",
+    {
+        "ExecutionId": str,
+        "InitialFileLocation": "FileLocationTypeDef",
+        "ServiceMetadata": "ServiceMetadataTypeDef",
+        "Status": ExecutionStatusType,
+    },
+    total=False,
+)
+
 _RequiredListedServerTypeDef = TypedDict(
     "_RequiredListedServerTypeDef",
     {
@@ -627,6 +925,25 @@ class ListedUserTypeDef(_RequiredListedUserTypeDef, _OptionalListedUserTypeDef):
     pass
 
 
+ListedWorkflowTypeDef = TypedDict(
+    "ListedWorkflowTypeDef",
+    {
+        "WorkflowId": str,
+        "Description": str,
+        "Arn": str,
+    },
+    total=False,
+)
+
+LoggingConfigurationTypeDef = TypedDict(
+    "LoggingConfigurationTypeDef",
+    {
+        "LoggingRole": str,
+        "LogGroupName": str,
+    },
+    total=False,
+)
+
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
@@ -676,6 +993,51 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
+S3FileLocationTypeDef = TypedDict(
+    "S3FileLocationTypeDef",
+    {
+        "Bucket": str,
+        "Key": str,
+        "VersionId": str,
+        "Etag": str,
+    },
+    total=False,
+)
+
+S3InputFileLocationTypeDef = TypedDict(
+    "S3InputFileLocationTypeDef",
+    {
+        "Bucket": str,
+        "Key": str,
+    },
+    total=False,
+)
+
+S3TagTypeDef = TypedDict(
+    "S3TagTypeDef",
+    {
+        "Key": str,
+        "Value": str,
+    },
+)
+
+SendWorkflowStepStateRequestRequestTypeDef = TypedDict(
+    "SendWorkflowStepStateRequestRequestTypeDef",
+    {
+        "WorkflowId": str,
+        "ExecutionId": str,
+        "Token": str,
+        "Status": CustomStepStatusType,
+    },
+)
+
+ServiceMetadataTypeDef = TypedDict(
+    "ServiceMetadataTypeDef",
+    {
+        "UserDetails": "UserDetailsTypeDef",
+    },
+)
+
 SshPublicKeyTypeDef = TypedDict(
     "SshPublicKeyTypeDef",
     {
@@ -707,6 +1069,15 @@ TagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
+TagStepDetailsTypeDef = TypedDict(
+    "TagStepDetailsTypeDef",
+    {
+        "Name": str,
+        "Tags": List["S3TagTypeDef"],
+    },
+    total=False,
+)
+
 TagTypeDef = TypedDict(
     "TagTypeDef",
     {
@@ -813,6 +1184,7 @@ _OptionalUpdateServerRequestRequestTypeDef = TypedDict(
         "LoggingRole": str,
         "Protocols": List[ProtocolType],
         "SecurityPolicyName": str,
+        "WorkflowDetails": "WorkflowDetailsTypeDef",
     },
     total=False,
 )
@@ -867,3 +1239,50 @@ UpdateUserResponseTypeDef = TypedDict(
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
+
+_RequiredUserDetailsTypeDef = TypedDict(
+    "_RequiredUserDetailsTypeDef",
+    {
+        "UserName": str,
+        "ServerId": str,
+    },
+)
+_OptionalUserDetailsTypeDef = TypedDict(
+    "_OptionalUserDetailsTypeDef",
+    {
+        "SessionId": str,
+    },
+    total=False,
+)
+
+
+class UserDetailsTypeDef(_RequiredUserDetailsTypeDef, _OptionalUserDetailsTypeDef):
+    pass
+
+
+WorkflowDetailTypeDef = TypedDict(
+    "WorkflowDetailTypeDef",
+    {
+        "WorkflowId": str,
+        "ExecutionRole": str,
+    },
+)
+
+WorkflowDetailsTypeDef = TypedDict(
+    "WorkflowDetailsTypeDef",
+    {
+        "OnUpload": List["WorkflowDetailTypeDef"],
+    },
+)
+
+WorkflowStepTypeDef = TypedDict(
+    "WorkflowStepTypeDef",
+    {
+        "Type": WorkflowStepTypeType,
+        "CopyStepDetails": "CopyStepDetailsTypeDef",
+        "CustomStepDetails": "CustomStepDetailsTypeDef",
+        "DeleteStepDetails": "DeleteStepDetailsTypeDef",
+        "TagStepDetails": "TagStepDetailsTypeDef",
+    },
+    total=False,
+)
